@@ -1,5 +1,5 @@
 library(psgp)
-
+set.seed(100)
 # set up data:
 data(meuse)
 coordinates(meuse) = ~x+y
@@ -21,15 +21,11 @@ psgpObject = createIntamapObject(
 checkSetup(psgpObject)
 
 # do interpolation steps:
-psgpObject = estimateParameters(psgpObject) #, idpRange = seq(0.25,2.75,.25), nfold=3) # faster
+psgpObject = estimateParameters(psgpObject)
 
 # make prediction
 psgpObject = spatialPredict(psgpObject)
-summary(psgpObject$predictions)
 
 # Plot prediction
-#grays = gray.colors(4, 0.55, 0.95)
-#image(psgpObject$predictions, col=grays)
-#X11()
-#plot(psgpObject)
-#plot(meuse, pch=1, cex=sqrt(meuse$value)/20, add=TRUE)
+# plotIntamap(psgpObject)
+# plotIntamap(meuse, pch=1, cex=sqrt(meuse$value)/20, add=TRUE)
